@@ -4,6 +4,8 @@ use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
 
+use NetAddr::IP::Lite ':lower';
+
 use App::Netdisco::Web::Plugin;
 
 register_device_tab({ id => 'netmap', label => 'Neighbors' });
@@ -40,8 +42,9 @@ sub _add_children {
 
 # d3 seems not to use proper ajax semantics, so get instead of ajax
 get '/ajax/data/device/netmap' => sub {
-    my $start = param('q');
-    return unless $start;
+    my $ip = NetAddr::IP::Lite->new(param('q'));
+    return unless $ip;
+    my $start = $ip->addr;
 
     my @devices = schema('netdisco')->resultset('Device')->search({}, {
       result_class => 'DBIx::Class::ResultClass::HashRefInflator',
